

set -ex



test -f ${PREFIX}/bin/x86_64-conda_cos7-linux-gnu-g++
test -f ${PREFIX}/bin/x86_64-conda-linux-gnu-g++
CXX=$(${PREFIX}/bin/*-gcc -dumpmachine)-g++
${CXX} -Wall tests/aligned_alloc.cpp -c -o cpp_aligned.o --std=c++17
${CXX} -Wall cpp_aligned.o -o cpp_aligned --std=c++17 && ./cpp_aligned
exit 0
